@@ -19,14 +19,11 @@ class WinMDIWindow(tk.Frame):
     def show(self):
         self.pack(fill="both", expand="yes")
 
+    def preview(self, child):
+        self.after(2, child.mainloop())
+
 
 class WinMDIChild(DevToplevel):
     def __init__(self, master: tk.Tk = None, title: str = ""):
         super(WinMDIChild, self).__init__(master=master, title=title)
 
-
-Root = DevWindow()
-MDI = WinMDIWindow(Root)
-MDI.show()
-MDI.add()
-Root.run()
